==> haskell-json-0.10-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 json
version:              0.10
visibility:           public
id:                   json-0.10-FLB0bBVAQPdLWtWznGWLWk
key:                  json-0.10-FLB0bBVAQPdLWtWznGWLWk
license:              BSD-3-Clause
copyright:            (c) 2007-2018 Galois Inc.
maintainer:           Iavor S. Diatchki (iavor.diatchki@gmail.com)
author:               Galois Inc.
synopsis:             Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.

    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.

category:             Web
abi:                  48e837b9bf7c6ca79a5402d140c3dc0a
exposed:              True
exposed-modules:
    Text.JSON Text.JSON.Generic Text.JSON.Pretty Text.JSON.ReadP
    Text.JSON.String Text.JSON.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/json-0.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/json-0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/json-0.10
hs-libraries:         HSjson-0.10-FLB0bBVAQPdLWtWznGWLWk
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    mtl-2.2.2 pretty-1.1.3.6 syb-0.7.2.1-CMeJWgSwItuEGmFSowZSJf
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-json/html/json.haddock
haddock-html:         /usr/share/doc/haskell-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-json-0.10-89-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 json
version:              0.10
visibility:           public
id:                   json-0.10-IBHcWwGIoxM3p46RVAenPe
key:                  json-0.10-IBHcWwGIoxM3p46RVAenPe
license:              BSD-3-Clause
copyright:            (c) 2007-2018 Galois Inc.
maintainer:           Iavor S. Diatchki (iavor.diatchki@gmail.com)
author:               Galois Inc.
synopsis:             Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.

    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.

category:             Web
abi:                  ae80c25fb488b6a422d8b2aec1792e26
exposed:              True
exposed-modules:
    Text.JSON Text.JSON.Generic Text.JSON.Pretty Text.JSON.ReadP
    Text.JSON.String Text.JSON.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/json-0.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/json-0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-json
hs-libraries:         HSjson-0.10-IBHcWwGIoxM3p46RVAenPe
depends:
    array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    mtl-2.2.2 pretty-1.1.3.6 syb-0.7.2.1-79xM5Iq1jcc1z2iUKi48dD
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-json/html/json.haddock
haddock-html:         /usr/share/doc/haskell-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
